@@ -3,12 +3,8 @@
 
 #define TAG_STATE  GTK_STATE_PRELIGHT
 
-// #define DEFAULT_LAT 49.02833
-// #define DEFAULT_LON  8.39042
-
 #ifndef USE_MAEMO
 #define DEFAULT_IMAGE_PATH       "/tmp/gpxview/"
-#define DEFAULT_IMAGE_PATH_HOME  ".gpxview/"
 #define DEFAULT_MMPOI_PATH       "gpxview_poi.db"
 #define DEFAULT_GARMIN_PATH      "garmin_overridden.gpx"
 #define DEFAULT_FIELDNOTES_PATH  "geocache_visits_%s.txt"
@@ -17,17 +13,32 @@
 /* internal memory card */
 #define DEFAULT_IMAGE_PATH       "/media/mmc2/gpxview/"
 #else
-#define DEFAULT_IMAGE_PATH       "/home/user/MyDocs/.gpxview/"
+#define DEFAULT_IMAGE_PATH       "/home/user/.gpxview/"
 #endif
 #define DEFAULT_MMPOI_PATH       "MyDocs/.documents/Maps/gpxview_poi.db"
 #define DEFAULT_GARMIN_PATH      "MyDocs/.documents/garmin_overridden.gpx"
 #define DEFAULT_FIELDNOTES_PATH  "MyDocs/.documents/geocache_visits_%s.txt"
 #endif
 
+#define DEFAULT_IMAGE_PATH_HOME  ".gpxview/"
+
 #define LOCALEDIR "/usr/share/locale"
 #define PACKAGE   "gpxview"
 
 // for osm-gps-map:
 #define USE_CAIRO
+#define ENABLE_OSD
+#define ENABLE_BALLOON
+
+#ifdef USE_MAEMO
+#define BIG_BALLOONS
+#endif
+
+#ifdef BIG_BALLOONS
+#define BALLOON_AREA_WIDTH       380
+#define BALLOON_AREA_HEIGHT      100
+#define BALLOON_CORNER_RADIUS     20
+#define OSM_GPS_MAP_OSD_DIAMETER  60
+#endif
 
 #endif // CONFIG_H
